<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Contact_Info extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-ct-info';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Info', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'icon', [
				'label' => esc_html__( 'Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
			]
		);	
		$this->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
		$this->add_control(
			'info_content', [
				'label' => esc_html__( 'Content', 'transpi-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
			]
		);	
		$this->end_controls_section();
        
	}


	protected function render() {
	$settings = $this->get_settings_for_display(); 
    ?>	
        <div class="transpi__contatc-info">
            <div class="info__content-icon">
                <?php \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); ?>
            </div>
            <div class="info__content-txt">
                <h4><?php echo wp_kses($settings['title'], true);?></h4>
                <?php echo wp_kses($settings['info_content'], true);?>
            </div>
        </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Contact_Info() );