<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Header_Template extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-header-temp';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Header', 'transpi-plugin' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'print_header_layout',
			[
				'label' => esc_html__( 'Header Layout', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'style',
			[
				'label' => esc_html__( 'Header Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => esc_html__( 'Header 1', 'transpi-plugin' ),
					'2'  => esc_html__( 'Header 2', 'transpi-plugin' ),
				]
			]
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'__header_top_info',
			[
				'label' => esc_html__( 'Header Top Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'enable_header_top',
			[
				'label' => esc_html__( 'Enable Header Top', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'transpi-plugin' ),
				'label_off' => esc_html__( 'Hide', 'transpi-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'h_phone_icon', [
				'label' => esc_html__( 'Phone icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'h_phone', [
				'label' => esc_html__( 'Phone', 'transpi-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'h_open_icon', [
				'label' => esc_html__( 'Open icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'h_open', [
				'label' => esc_html__( 'Opening Text', 'transpi-plugin' ),
				'default' => esc_html__( 'Monday to Friday: 9:00am - 6:00pm', 'transpi-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		
		$repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'icons', [
				'label' => esc_html__( 'Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
			]
		);
        
        $repeater->add_control(
			'link', [
				'label' => esc_html__( 'Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);

        $this->add_control(
			'hsocials',
			[
				'label' => esc_html__( 'Add Social Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'default' => [
					[
						'icons' => [
							'value'   => 'fab fa-facebook-f',
                    		'library' => 'solid',
						],
						'link' => esc_html__( 'https://facebook.com', 'transpi-plugin' ),
						'title' => 'facebook',
					],
					[
						'icons' => [
							'value'   => 'fab fa-instagram',
                    		'library' => 'solid',
						],
						'link' => esc_html__( 'https://instagram.com', 'transpi-plugin' ),
						'title' => 'instagram',
					],
					[
						'icons' => [
							'value'   => 'fab fa-youtube',
                    		'library' => 'solid',
						],
						'link' => esc_html__( 'https://youtube.com', 'transpi-plugin' ),
						'title' => 'youtube',
					],
				],
				'fields' => $repeater->get_controls(),
				'condition' => [
					'enable_header_top' => 'yes',
					'style' => ['1', '2'],
				],
			]
		);

		$this->add_control(
			'career_icon', [
				'label' => esc_html__( 'Career Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'career', [
				'label' => esc_html__( 'Career Text', 'transpi-plugin' ),
				'default' => esc_html__( 'Career', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'career_link', [
				'label' => esc_html__( 'Career Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'condition', [
				'label' => esc_html__( 'Condition Text', 'transpi-plugin' ),
				'default' => esc_html__( 'Terms & Conditions', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'con_link', [
				'label' => esc_html__( 'Condition Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		
		$this->end_controls_section();

        $this->start_controls_section(
			'__header_logs',
			[
				'label' => esc_html__( 'Header Logo Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'__rzlogo', [
				'label' => esc_html__( 'Logo', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
				'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
			]
		);
		
		$this->add_responsive_control(
			'__rzlogo_size',
			[
				'label' => esc_html__( 'Max Width', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 5000,
					]
				],

				'selectors' => [
					'{{WRAPPER}} .transpi_logo img' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'__rzlogo_mobile', [
				'label' => esc_html__( 'Mobile Logo', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
				'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
			]
		);
		$this->add_control(
			'__search_mobile', [
				'label' => esc_html__( 'Search Logo', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
				'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
			]
		);
		
		$this->add_control(
            'enable_custom_link',
            [
                'label'        => __( 'Enable Custom Link', 'transpi-plugin' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'transpi-plugin' ),
                'label_off'    => __( 'No', 'transpi-plugin' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        // custom link
        $this->add_control(
            'custom_link',
            [
                'label'       => __( 'Custom Link', 'transpi-plugin' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'transpi-plugin' ),
                'show_label'  => false,
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'enable_m_custom_link' => 'yes',
                ],
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
			'menu_select',
			[
				'label' => esc_html__( 'Menu Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'choose-menu',
			[
				'label' => esc_html__( 'Choose menu', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => transpi_menu_selector(),
				'multiple' => false
			]
		);
		$this->add_control(
			'btn_label', [
				'label' => esc_html__( 'Button Label', 'transpi-plugin' ),
				'default' => esc_html__( 'Track Your Order', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'btn_link', [
				'label' => esc_html__( 'Button Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->add_control(
			'lang_search',
			[
				'label' => esc_html__( 'Enable or Disable Search', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'transpi-plugin' ),
				'label_off' => esc_html__( 'Hide', 'transpi-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'lang_hide',
			[
				'label' => esc_html__( 'Enable or Disable Languages', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'transpi-plugin' ),
				'label_off' => esc_html__( 'Hide', 'transpi-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'act_flag_img', [
				'label' => esc_html__( 'Active Flag Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
		$repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'lang', [
				'label' => esc_html__( 'Languages Name', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'flag_img', [
				'label' => esc_html__( 'Flag Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);

        $this->add_control(
			'languages',
			[
				'label' => esc_html__( 'Add Languages Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'condition' => [
					'style' => ['1', '2'],
				],
			]
		);
		$this->end_controls_section();
        
		$this->start_controls_section(
			'menu_bar_style',
			[
				'label' => esc_html__( 'Menu Top Bar Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'meni--styl',
			[
				'label' => esc_html__( 'Header Top BG Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'header_top_bar_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
				{{WRAPPER}} .ptx-header-top-section,
				{{WRAPPER}} .ptx-header-section.type_four .header-top-content .top-cta .inner-icon i,
				{{WRAPPER}} .ptx-header-section.type_four .ptx-header-menu-social-area
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Header Top Bar BG', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
                ]
			]
		);
		$this->add_control(
			'top-txt-styl',
			[
				'label' => esc_html__( 'Header Top Text Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'top-text-c',
			[
				'label' => esc_html__( 'Text Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-header-top-section li' => 'color: {{VALUE}}',
				],
			]
		);


        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'top_text_typography',
				'selector' => '{{WRAPPER}} .ptx-header-top-section li',
			]
		);
		$this->add_control(
			'store--styl',
			[
				'label' => esc_html__( 'Store Location Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'top-str-c',
			[
				'label' => esc_html__( 'Store Location Text Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .top-location' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'str_typography',
				'selector' => '{{WRAPPER}} .top-location',
			]
		);
		$this->add_control(
			'store-social-styl',
			[
				'label' => esc_html__( 'Social Icon Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'style' => ['2'],
				],
			]
		);
		$this->add_control(
			'top-social-c',
			[
				'label' => esc_html__( 'Social Icon Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-header-top-section li' => 'color: {{VALUE}}',
				],
				'condition' => [
					'style' => ['2'],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'menu_info_style',
			[
				'label' => esc_html__( 'Menu Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'main-mennu--styl',
			[
				'label' => esc_html__( 'Main Menu Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		
        $this->add_control(
			'menu-text-c',
			[
				'label' => esc_html__( 'Menu Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-header-main-menu-area .main-navigation li a' => 'color: {{VALUE}}',
					'{{WRAPPER}} .main-navigation li a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'menu-hover-c',
			[
				'label' => esc_html__( 'Menu Hover Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-header-main-menu-area .main-navigation li:hover a, .ptx-header-section .dropdown:hover a:after' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .ptx-header-section .dropdown-menu a:hover' => 'color: {{VALUE}} !important'
				],
			]
		);
        $this->add_control(
			'menu-hover-bg',
			[
				'label' => esc_html__( 'Menu Hover BG Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-header-section.type_four .main-navigation li a:before' => 'background: {{VALUE}} !important',
				],
				'condition' => [
					'style' => ['4'],
				],
			]
		);


        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'menu_tct_typography',
				'selector' => '
					{{WRAPPER}} .ptx-header-main-menu-area .main-navigation li a,
					{{WRAPPER}} .main-navigation li a
				',
			]
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'menu_livechat_style',
			[
				'label' => esc_html__( 'Live Chat Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'live-mennu--styl',
			[
				'label' => esc_html__( 'Live Chat Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'live_top_bar_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
				{{WRAPPER}} .header-cta .inner-icon i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Gradient Icon BG', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
                ]
			]
		);

		$this->add_control(
			'lvc-title-c',
			[
				'label' => esc_html__( 'Title Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-cta .inner-text span' => 'background: {{VALUE}}; background-clip: text;
					-webkit-background-clip: text;
					-webkit-text-fill-color: transparent; ',
				],
			]
		);


        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'menu_live_typography',
				'selector' => '{{WRAPPER}} .header-cta .inner-text span',
			]
		);
		$this->add_control(
			'live-text--styl',
			[
				'label' => esc_html__( 'Live Text Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'lvc-text-c',
			[
				'label' => esc_html__( 'Menu Hover Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-cta .inner-text a' => 'color: {{VALUE}} ',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'menu_live_txt_typography',
				'selector' => '{{WRAPPER}} .header-cta .inner-text a',
			]
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'slider_button_one',
			[
				'label' => esc_html__( 'Button Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'm_b_typography',
				'selector' => '{{WRAPPER}} .ptx-btn-1 a, .ptx-btn-2 a, .ptx-btn-3 a, .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a',
			]
		);
        $this->add_control(
			'padding',
			[
				'label' => esc_html__( 'Padding', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-1 a, .ptx-btn-2 a, .ptx-btn-3 a, .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        $this->add_control(
			'b_round',
			[
				'label' => esc_html__( 'Border Radius', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-1 a, .ptx-btn-2 a, .ptx-btn-3 a, .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        $this->add_control(
			'btn_text',
			[
				'label' => esc_html__( 'Text Color', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-1 a, .ptx-btn-2 a, .ptx-btn-3 a, .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'button_bg_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .ptx-btn-1 a, .ptx-btn-2 a, .ptx-btn-3 a, .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
                ]
			]
		);
        
        $this->end_controls_section();



	}


	/**
	 * Main Contetn
	 *
	 * @return void
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		extract( $settings );

		$enable_custom_link = $enable_custom_link;

		if($enable_custom_link == 'yes') {
			$custom_link = $custom_link['url'];
		} else {
			$custom_link = home_url( '/' );
		}

		require __DIR__ . '/template-view/header/header-' . $style . '.php';
    }

	/**
	 * Search Body Display
	 *
	 * @return void
	 */
	protected function ___search_body(){
		$settings = $this->get_settings_for_display();
		extract( $settings );
		?>
		<div class="search__popup">
			<div class="container">
				<div class="row">
					<div class="col-xl-12">
					<div class="main_search__wrapper">
						<div class="search__top d-flex justify-content-between align-items-center">
							<div class="search__logo">
							<?php if(!empty($__rzlogo['url'])):?>
								<div class="transpi_logo">
									<a href="<?php echo esc_url(home_url());?>"><img src="<?php echo esc_url($__search_mobile['url']);?>" alt=""></a>
								</div>
							<?php endif;?>
							</div>
							<div class="bar_search__close">
								<button type="button" class="bar_search__close-btn search-close-btn">                           
									<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>                                
								</button>
							</div>
						</div>
						<div class="search__form">
							<form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
								<div class="search__input">
								<input class="search-input-field" type="text" placeholder="<?php esc_attr_e( 'Search ...', 'btourq' )?>" name="s" value="<?php the_search_query();?>">
								<span class="search-focus-border"></span>
								<button type="submit">
									<svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
										<path d="M9.55 18.1C14.272 18.1 18.1 14.272 18.1 9.55C18.1 4.82797 14.272 1 9.55 1C4.82797 1 1 4.82797 1 9.55C1 14.272 4.82797 18.1 9.55 18.1Z" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path>
										<path d="M19.0002 19.0002L17.2002 17.2002" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path>
									</svg> 
								</button>
								</div>
							</form>
						</div>
					</div>
					</div>
				</div>
			</div>
		</div>
<?php 
	}



	/**
	 * Mobile Menu Display
	 *
	 * @return void
	 */
	protected function __mobile_menu(){ 
		$settings = $this->get_settings_for_display();
		$enable_m_custom_link = $settings['enable_m_custom_link'];
		$m_custom_link = '';
		if($enable_m_custom_link == 'yes') {
			$m_custom_link = $settings['m_custom_link']['url'];
		} else {
			$m_custom_link = home_url( '/' );
		}	
	?>

	<?php }

	/**
	 * Mobile Menu
	 *
	 * @return void
	 */
	protected function mobile_menu(){ 
		$settings = $this->get_settings_for_display();	
	?>
		<div class="slide-bar">
			<div class="close-mobile-menu">
				<a href="javascript:void(0);"><i class="fal fa-times"></i></a>
			</div>
			<nav class="side-mobile-menu">
				<?php if(!empty($settings['__rzlogo_mobile']['url'])):?>
					<div class="transpi_logo">
						<a href="<?php echo esc_url(home_url( '/' ));?>"><img src="<?php echo esc_url($settings['__rzlogo_mobile']['url']);?>" alt=""></a>
					</div>
				<?php endif;?>
				<div class="header-mobile-search">
					<form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
						<input type="search" name="s" id="search-id" value="<?php the_search_query();?>" placeholder="<?php esc_attr_e( 'Search Here', 'btourq' )?>">
						<button type="submit"><i class="ti-search"></i></button>
					</form>
				</div>
				<?php
					echo str_replace(['menu-item-has-children'], ['dropdown'], wp_nav_menu( array(
						'echo'           => false,
						'menu' => !empty($settings['choose-menu']) ? $settings['choose-menu'] : 'menu-1',
						'menu_id'        =>'transpi-mobile-menu',
						'menu_class'        =>'transpi-mobile-menu',
						'container'=>false,
						'fallback_cb'    => 'Navwalker_Class::fallback',
						'walker'         => class_exists( 'Rs_Mega_Menu_Walker' ) ? new \Rs_Mega_Menu_Walker : '',
					)) );
				?>
			</nav>
		</div>
	<?php
	}


}


Plugin::instance()->widgets_manager->register( new Transpi_Header_Template() );