<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Testimonial extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-testimonial-carousel';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonial Carousel', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		
		$repeater = new \Elementor\Repeater();
        $repeater->add_control(
			'dur', [
				'label' => esc_html__( 'Animation Duration', 'transpi-plugin' ),
				'placeholder' => esc_html__( '200ms', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
		$repeater->add_control(
			'icon', [
				'label' => esc_html__( 'Service Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
			]
		);
        
        $repeater->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'feedback', [
				'label' => esc_html__( 'Feedback', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'name', [
				'label' => esc_html__( 'Name', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'designation', [
				'label' => esc_html__( 'Designation', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'authore_img', [
				'label' => esc_html__( 'Authore Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
        
        $this->add_control(
			'testimonial',
			[
				'label' => esc_html__( 'Add Testimonial Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
			]
		);		
				
		$this->end_controls_section();

		$this->start_controls_section(
			'widget_con_style',
			[
				'label' => esc_html__( 'Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'f_title',
			[
				'label' => esc_html__( 'Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'f_title_color',
			[
				'label' => esc_html__( 'Title Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-sec-title' => 'color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'title_gd_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-item-content .slider-item-text .ptx-section-title-4 .ptx-sec-title span
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Title Gradient Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'f_title_typography',
				'selector' => '{{WRAPPER}} .ptx-sec-title',
			]
		);

		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'subtitle_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle span,
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle:before, .ptx-section-title-4.ver_2 .ptx-subtitle:after,
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Sub Title Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sub_typography',
				'selector' => '
				{{WRAPPER}} .ptx-subtitle span',
			]
		);

		$this->add_control(
			'desc_style',
			[
				'label' => esc_html__( 'Desc Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'desc_color',
			[
				'label' => esc_html__( 'Description Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'count_typography',
				'selector' => '
				{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p,
				{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p
				',
			]
		);
        $this->add_control(
			'btn_style',
			[
				'label' => esc_html__( 'Button Style Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'btn_bg_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a, .slider-video-btn i, .slider-video-btn.ver_2 i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		$this->add_control(
			'btn__color',
			[
				'label' => esc_html__( 'Button Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_typography',
				'selector' => '
				{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a',
			]
		);
        $this->add_control(
			'nivatig_style',
			[
				'label' => esc_html__( 'Slider Arrwo Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_arrwo_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-main-arrow-next-prev .ptx-slider-arrow:hover:before, .ptx-main-arrow-next-prev .swiper-main-paginations .swiper-pagination-bullet.swiper-pagination-bullet-active, .ptx-main-arrow-next-prev .swiper-main-pagination2 .swiper-pagination-bullet.swiper-pagination-bullet-active
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
        $this->add_control(
			'social_style',
			[
				'label' => esc_html__( 'Social Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_border_color',
			[
				'label' => esc_html__( 'Border Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-slider-social li a' => 'border-color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_social_icon_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-social li a i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Social Icon Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->end_controls_section();
        
	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>	
        <div class="thm-swiper__testimonial-wrapper">
        <div class="swiper-container thm-swiper__testimonial">

            <div class="swiper-wrapper">
                <?php foreach($settings['testimonial'] as $item):?>
                <div class="swiper-slide">
                    <div class="transpi__testimonial-item wow fadeInUp" <?php if(!empty($item['dur'])):?> data-wow-delay="<?php echo esc_attr($item['dur']);?>" <?php endif;?> data-wow-duration="1000ms">
                        <div class="transpi__testimonial-item-inner">
                            <div class="quote_icon">
                                <?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
                            </div>
                            <?php if(!empty($item['title'])):?>
                            <h3><?php echo esc_html($item['title']);?></h3>
                            <?php endif;?>
                            <?php if(!empty($item['feedback'])):?>
                                <p><?php echo wp_kses($item['feedback'], true);?></p>
                            <?php endif;?>
                            <div class="testi__auth">
                                <?php if(!empty($item['authore_img']['url'])):?>
                                    <div class="autho__img">
                                        <img src="<?php echo esc_url($item['authore_img']['url']);?>" alt="">
                                    </div>
                                <?php endif;?>
                                <div class="autho__info">
                                    <h4><?php echo esc_html($item['name']);?></h4>
                                    <span><?php echo esc_html($item['designation']);?></span>
                                </div>
                            </div>
                        </div>
                        <div class="tes__shape">
                            <svg xmlns="http://www.w3.org/2000/svg" width="425" height="402" viewBox="0 0 425 402" fill="none">
                                <path d="M302.775 1H21C9.95431 1 1 9.95431 1 21V381C1 392.046 9.95431 401 21 401H404C415.046 401 424 392.046 424 381V98.9364C424 92.7302 421.119 86.8755 416.201 83.0893L314.976 5.15288C311.478 2.46014 307.188 1 302.775 1Z" stroke="#DBDBDB"/>
                            </svg>
                        </div>
                    </div>
                </div>
                <?php endforeach;?>

            </div>


            </div>

            <div class="swiper-pagination testimonial-one__dot-style1" id="swiper-dot-style3"></div>
            </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Testimonial() );