<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Accordion extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranpi-accordion-';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Transpi Accordion', 'transpi-plugin' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'printox_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
        
		$repeater = new \Elementor\Repeater();
		
        $repeater->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'description', [
				'label' => esc_html__( 'Description', 'transpi-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
			]
		);
        
        $this->add_control(
			'accordions',
			[
				'label' => esc_html__( 'Add Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
			]
		);		
		$this->end_controls_section();

		$this->start_controls_section(
			'widget_tab_style',
			[
				'label' => esc_html__( 'Tab Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'tb_title',
			[
				'label' => esc_html__( 'Accordion Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'tb_title_color',
			[
				'label' => esc_html__( 'Title Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .trans__ac-item .accordion-button' => 'color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'gd_title_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .trans__ac-item .accordion-button
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Gradient BG Color ', 'gesto-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'gesto-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'tb_title_typography',
				'selector' => '{{WRAPPER}} .trans__ac-item .accordion-button',
			]
		);
		$this->add_control(
			'ac_text_title',
			[
				'label' => esc_html__( 'Accordion Text Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'ac_txt',
			[
				'label' => esc_html__( 'Text Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bi-faq-text p' => 'color: {{VALUE}}'
				],
			]
		);
        
		
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ac_text_typography',
				'selector' => '{{WRAPPER}} .bi-faq-text p',
			]
		);
		$this->end_controls_section();
        
	}


	protected function render() {
		$settings = $this->get_settings_for_display();	
        if ( ! empty( $settings['btn_link']['url'] ) ) {
			$this->add_link_attributes( 'btn_link', $settings['btn_link'] );
		}
        $rnad_nm = rand( 1245, 6698 );
    ?>
    <div class="transpi-accordion-wrapper">
        <div class="trans__ac-item">
                <div class="accordion" id="accordionExample_<?php echo esc_attr($rnad_nm);?>">
                <?php foreach ($settings['accordions'] as $id => $item) :
                    $collapsed_tab = ($id == 0) ? '' : 'collapsed';
                    $area_expanded = ($id == 0) ? 'true' : 'false';
                    $active_show_tab = ($id == 0) ? 'show' : '';
                ?>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="heading<?php print esc_attr( $rnad_nm );?>-<?php echo esc_attr( $id ); ?>">
                            <button class="accordion-button <?php echo esc_attr($collapsed_tab); ?>" type="button" data-bs-toggle="collapse" data-bs-target="#collapse<?php print esc_attr( $rnad_nm );?>-<?php echo esc_attr( $id ); ?>" aria-expanded="<?php echo esc_attr($area_expanded); ?>" aria-controls="collapse<?php print esc_attr( $rnad_nm );?>-<?php echo esc_attr( $id ); ?>">
                                <span>	<?php echo wp_kses($item['title'], true);?></span>
                            </button>
                        </h2>
                        <div id="collapse<?php print esc_attr( $rnad_nm );?>-<?php echo esc_attr( $id ); ?>" class="accordion-collapse collapse <?php echo esc_attr($active_show_tab); ?>" aria-labelledby="heading<?php print esc_attr( $rnad_nm );?>-<?php echo esc_attr( $id ); ?>" data-bs-parent="#accordionExample_<?php print esc_attr( $rnad_nm );?>">
                            <div class="accordion-body ">
                                <div class="bi-faq-text">
                                    <?php echo wp_kses($item['description'], true);?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
    <?php 
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Accordion() );