<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Team extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-team';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'dur', [
				'label' => esc_html__( 'Animation Duration', 'transpi-plugin' ),
				'placeholder' => esc_html__( '200ms', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
		$this->add_control(
			'team_img', [
				'label' => esc_html__( 'Team Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);	
		$this->add_control(
			'title', [
				'label' => esc_html__( 'Name', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
		$this->add_control(
			'designation', [
				'label' => esc_html__( 'Designation', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
		$this->add_control(
			'link', [
				'label' => esc_html__( 'Link To Single Page', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);	
        $repeater = new \Elementor\Repeater();
        
		$repeater->add_control(
			'icon', [
				'label' => esc_html__( 'Service Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
			]
		);
        
        $repeater->add_control(
			'link', [
				'label' => esc_html__( 'link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $this->add_control(
			'socials',
			[
				'label' => esc_html__( 'Add Social Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			]
		);	
		$this->end_controls_section();
        
	}


	protected function render() {
	$settings = $this->get_settings_for_display(); 
    ?>	
        <div class="transpi__team-item wow fadeInUp" <?php if(!empty($settings['dur'])):?> data-wow-delay="<?php echo esc_attr($settings['dur']);?>" <?php endif;?> data-wow-duration="1000ms">
            <div class="team__top">
                <div class="team_img">
					<img src="<?php echo esc_url($settings['team_img']['url']);?>" alt="">
				</div>
                <div class="team_overlay">
                    <span class="tm_hover"><i class="fal fa-share-alt"></i></span>
                    <div class="social_icon">
                        <?php foreach($settings['socials'] as $item):?>
                            <a class="<?php if(!empty($item['title'])){ echo esc_attr($item['title']);}?>" href="<?php echo esc_url($item['link']['url']);?>"><?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?></a>
                        <?php endforeach;?>
                    </div>
                </div>
            </div>
            <div class="team_content">
                <h3><a href="<?php echo esc_url($settings['link']['url']);?>"><?php echo esc_html($settings['title']);?></a></h3>
                <span><?php echo esc_html($settings['designation']);?></span>
            </div>
        </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Team() );