<?php
/**
 * transpi functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package transpi
 */

 define( 'TRANSPI_THEME_DRI', get_template_directory() );
 define( 'TRANSPI_INC_DRI', get_template_directory() . '/inc/' );
 define( 'TRANSPI_THEME_URI', get_template_directory_uri() );
 define( 'TRANSPI_CSS_PATH', TRANSPI_THEME_URI . '/assets/css' );
 define( 'TRANSPI_JS_PATH', TRANSPI_THEME_URI . '/assets/js' );
 define( 'TRANSPI_IMG_PATH', TRANSPI_THEME_URI . '/assets/images' );
 define( 'TRANSPI_ADMIN_DRI', TRANSPI_THEME_DRI . '/admin' );
 
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function transpi_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on transpi, use a find and replace
		* to change 'transpi' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'transpi', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	add_image_size('transpi-img-size', 873, 480, true);
	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );
	remove_theme_support( 'widgets-block-editor' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	//Woocommerc
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'transpi' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'transpi_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

}
add_action( 'after_setup_theme', 'transpi_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function transpi_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'transpi_content_width', 640 );
}
add_action( 'after_setup_theme', 'transpi_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function transpi_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'transpi' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'transpi' ),
			'before_widget' => '<div id="%1$s" class="transpi__sidebar-item %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Shop Siderbar', 'transpi' ),
			'id'            => 'shop-sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'transpi' ),
			'before_widget' => '<div id="%1$s" class="widget mt-30 %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget__title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'transpi_widgets_init' );



/**
 *Google Font Load 
 */
if ( ! function_exists( 'transpi_fonts_url' ) ) :
	
	function transpi_fonts_url() {
		$fonts_url     = '';
		$font_families = array();
		$subsets       = 'latin';
	
	
		if ( 'off' !== _x( 'on', 'DM Sans: on or off', 'transpi' ) ) {
			$font_families[] = 'DM Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i,1000,1000i';
		}
		if ( 'off' !== _x( 'on', 'Outfit: on or off', 'transpi' ) ) {
			$font_families[] = 'Outfit:200,300,400,500,600,700,800,900';
		}
	
		if ( $font_families ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}
	
		return esc_url_raw( $fonts_url );
	}
	endif;


/**
 * Enqueue scripts and styles.
 */
function transpi_scripts() {

	wp_enqueue_style( 'transpi-google-fonts', transpi_fonts_url(), array(), null );

	wp_enqueue_style( 'bootstrap', TRANSPI_CSS_PATH . '/bootstrap.min.css' );
	wp_enqueue_style( 'fontawesome', TRANSPI_CSS_PATH . '/fontawesome.css' );
	wp_enqueue_style( 'e-animations', TRANSPI_CSS_PATH . '/animate.css' );
	wp_enqueue_style( 'odometer', TRANSPI_CSS_PATH . '/odometer.css' );
	wp_enqueue_style( 'metis-menu', TRANSPI_CSS_PATH . '/metis-menu.css' );
	wp_enqueue_style( 'range-slider', TRANSPI_CSS_PATH . '/range-slider.css' );
	wp_enqueue_style( 'transpi-swiper', TRANSPI_CSS_PATH . '/swiper.min.css' );
	wp_enqueue_style( 'magnific-popup', TRANSPI_CSS_PATH . '/magnific-popup.css' );
	wp_enqueue_style( 'transpi-core', TRANSPI_CSS_PATH . '/transpi-core.css' );
	wp_enqueue_style( 'transpi-responsive', TRANSPI_CSS_PATH . '/responsive.css' );

	if (is_rtl()) {		
		wp_enqueue_style( 'transpi-rtl', TRANSPI_CSS_PATH . '/rtl.css' );
	}

	wp_enqueue_style( 'transpi-style', get_stylesheet_uri(), array() );

	wp_enqueue_script('jquery-ui-core');
	wp_enqueue_script( 'jquery-ui-slider' );
	wp_enqueue_script( 'bootstrap', TRANSPI_JS_PATH . '/bootstrap.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'transpi-swiper-bundle', TRANSPI_JS_PATH . '/swiper-bundle.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'appear', TRANSPI_JS_PATH . '/appear-min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'rangeslider', TRANSPI_JS_PATH . '/rangeslider.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'magnific-popup', TRANSPI_JS_PATH . '/jquery.magnific-popup.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'metisMenu', TRANSPI_JS_PATH . '/metisMenu.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'smoothscroll-varticle', TRANSPI_JS_PATH . '/smoothscroll-varticle.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'odometer', TRANSPI_JS_PATH . '/odometer.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'gsap', TRANSPI_JS_PATH . '/gsap.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'ScrollTrigger', TRANSPI_JS_PATH . '/ScrollTrigger.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'tilt-jquery', TRANSPI_JS_PATH . '/tilt.jquery.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'wow', TRANSPI_JS_PATH . '/wow.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'SplitText', TRANSPI_JS_PATH . '/splittext.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'transpi-core', TRANSPI_JS_PATH . '/transpi-core.js', array('jquery', 'transpi-swiper-bundle'), time(), true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'transpi_scripts' );

/**
 * Implement the Custom Header feature.
 */
require TRANSPI_THEME_DRI . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require TRANSPI_THEME_DRI . '/inc/template-tags.php';
/**
 * Breadcrumb
 */
require TRANSPI_THEME_DRI . '/inc/breadcrumb-core.php';

/**
 * Custom template tags for this theme.
 */
require TRANSPI_THEME_DRI . '/inc/class-wp-transpi-navwalker.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require TRANSPI_THEME_DRI . '/inc/template-functions.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require TRANSPI_THEME_DRI . '/inc/transpi-functions.php';

/**
 * Cs Fremwork Config
 */
require TRANSPI_THEME_DRI . '/inc/cs-framework-functions.php';

/**
 * Dynamic Style
 */
require TRANSPI_THEME_DRI . '/inc/dynamic-style.php';

/**
 * transpi Core Functions
 */
require TRANSPI_THEME_DRI . '/inc/transpi-helper-class.php';

/**
 * transpi Core Functions
 */
require TRANSPI_THEME_DRI . '/inc/admin/class-admin-dashboard.php';

/**
 * transpi Core Functions
 */
require TRANSPI_THEME_DRI . '/inc/admin/demo-import/functions.php';

/**
 * Customizer additions.
 */
require TRANSPI_THEME_DRI . '/inc/customizer.php';


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require TRANSPI_THEME_DRI . '/inc/jetpack.php';
}

/**
 * Remove Action Hook
 */

 function transpi_woo_theme_init(){
	$transpi_exlude_hooks = require TRANSPI_THEME_DRI . '/inc/remove_actions.php';
	foreach( $transpi_exlude_hooks as $k => $v )
	{
		foreach( $v as $value )
		remove_action( $k, $value[0], $value[1] );
	}

}
add_action( 'init', 'transpi_woo_theme_init');

function transpi_megamenu_enable() {
	return true;
}
add_filter( 'th_enable_megamenu', 'transpi_megamenu_enable' );
